==> iReport-nb-0.9.1-src.zip: iReport-nb-0.9.1-src/ireport-designer/src/com/jaspersoft/ireport/designer/sheet/properties/ConnectionExpressionProperty.java <==
/*
 * ElementPropertiesFactory.java
 * 
 * Created on 31-ott-2007, 23.03.43
 * 
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package com.jaspersoft.ireport.designer.sheet.properties;

import java.sql.Connection;
import net.sf.jasperreports.engine.design.JRDesignDataset;
import net.sf.jasperreports.engine.design.JRDesignExpression;
import net.sf.jasperreports.engine.design.JRDesignSubreport;

    
/**
 * Class to manage the JRDesignSubreport.PROPERTY_CONNECTION_EXPRESSION property.
 */
public final class ConnectionExpressionProperty extends ExpressionProperty 
{
    private final JRDesignSubreport subreport;

    public ConnectionExpressionProperty(JRDesignSubreport subreport, JRDesignDataset dataset)
    {
        super(subreport, dataset);
        this.subreport = subreport;
    }

    @Override
    public String getName()
    {
        return JRDesignSubreport.PROPERTY_CONNECTION_EXPRESSION;
    }

    @Override
    public String getDisplayName()
    {
        return "Connection Expression";
    }

    @Override
    public String getShortDescription()
    {
        return "The expression must return a java.sql.Connection object to fill the subreport.";
    }

    @Override
    public String getDefaultExpressionClassName()
    {
        return Connection.class.getName();
    }

    @Override
    public JRDesignExpression getExpression()
    {
        return (JRDesignExpression)subreport.getConnectionExpression();
    }

    @Override
    public void setExpression(JRDesignExpression expression)
    {
        subreport.setConnectionExpression(expression);
    }

    @Override
    public boolean canWrite() 
    {
        return getExpression() != null;
    }

    @Override
    public String getHtmlDisplayName() {
        if (!canWrite())
        {
            return "<font color=\"#CCCCCC\">" + getDisplayName() + "</font>";
        }
        return super.getHtmlDisplayName();
    }
}

==> iReport-nb-3.1.3-src.zip: iReport-nb-3.1.3-src/ireport-designer/src/com/jaspersoft/ireport/designer/sheet/properties/ConnectionExpressionProperty.java <==
/*
 * ElementPropertiesFactory.java
 * 
 * Created on 31-ott-2007, 23.03.43
 * 
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package com.jaspersoft.ireport.designer.sheet.properties;

import com.jaspersoft.ireport.locale.I18n;
import java.sql.Connection;
import net.sf.jasperreports.engine.design.JRDesignDataset;
import net.sf.jasperreports.engine.design.JRDesignExpression;
import net.sf.jasperreports.engine.design.JRDesignSubreport;

    
/**
 * Class to manage the JRDesignSubreport.PROPERTY_CONNECTION_EXPRESSION property.
 */
public final class ConnectionExpressionProperty extends ExpressionProperty 
{
    private final JRDesignSubreport subreport;

    public ConnectionExpressionProperty(JRDesignSubreport subreport, JRDesignDataset dataset)
    {
        super(subreport, dataset);
        this.subreport = subreport;
    }

    @Override
    public String getName()
    {
        return JRDesignSubreport.PROPERTY_CONNECTION_EXPRESSION;
    }

    @Override
    public String getDisplayName()
    {
        return I18n.getString("Global.Property.ConnectionExpression");
    }

    @Override
    public String getShortDescription()
    {
        return I18n.getString("Global.Property.ConnectionExpressiondetail");
    }

    @Override
    public String getDefaultExpressionClassName()
    {
        return Connection.class.getName();
    }

    @Override
    public JRDesignExpression getExpression()
    {
        return (JRDesignExpression)subreport.getConnectionExpression();
    }

    @Override
    public void setExpression(JRDesignExpression expression)
    {
        subreport.setConnectionExpression(expression);
    }

    @Override
    public boolean canWrite() 
    {
        return getExpression() != null;
    }

    @Override
    public String getHtmlDisplayName() {
        if (!canWrite())
        {
            return "<font color=\"#CCCCCC\">" + getDisplayName() + "</font>";
        }
        return super.getHtmlDisplayName();
    }
}
